/*************************************************************************

    File: laraPredicates.pl
    Copyright (C) 2008 Johannes Dellert

    This file is part of LARA, version 1.0 (August 2008).

    Original file: curtPredicates.pl
    Copyright (C) 2004,2005,2006 Patrick Blackburn & Johan Bos

    That file was part of BB1, version 1.3 (November 2006).


*************************************************************************/

:- module(laraPredicates,[laraHelp/0,
                          laraOutput/1,
                          updateReadings/1,
                          updateModels/1,
                          updateHistory/1,
                          clearHistory/0,
                          list2string/2,
                          selectReadings/3]).

:- use_module(comsemPredicates,[appendLists/3]).


/*========================================================================
   Lara Help
========================================================================*/

laraHelp:-
   nl, write('interpretoj: printas la interpretojn aktualajn'),
   nl, write('elektu N: elektu interpreton (N devas esti entjero)'),
   nl, write('denove: iniciatas novan diskurson'),
   nl, write('historio: montras la diskurson gxis nun'),
   nl, write('modeloj: printas la modelojn aktualajn'),
   nl, write('resumo: eliminas interpretojn ekvivalentajn'),
   nl, write('scio: kalkulas kaj montras fonan scion'),
   nl, write('infikso: vidigu formulojn en infiksa notado'),
   nl, write('prefikso: vidigu formulojn en prefiksa notado'),
   nl, write('gxis: forlasi Laran'),
   nl.


/*========================================================================
   Lara's output
========================================================================*/

laraOutput([]).

laraOutput([Move|Moves]):-
   realiseMove(Move,Output),
   format('~nLara: ~p~n',[Output]),
   laraOutput(Moves).


/*========================================================================
   Lara's Moves
========================================================================*/

realiseMove(clarify,'Cxu vi volas diri ion?').
realiseMove(bye,'Gxis revido!').
realiseMove(accept,'Okej.').
realiseMove(noparse,'Kio?').
realiseMove(contradiction,'Ne! Mi ne kredas tion!').
realiseMove(obvious,'Nu, tio estas evidenta!').
realiseMove(unknown_answer,'Mi ne havas ideon.').
realiseMove(sensible_question,'Senca demando!').
realiseMove(answer(String),String).


/*========================================================================
   Select Readings
========================================================================*/

selectReadings(X,R1,R2):-
   selectReadings(1,X,R1,R2).

selectReadings(X,X,[R|_],[R]).

selectReadings(X,Y,[_|L],R):-
   X < Y,
   Z is X + 1,
   selectReadings(Z,Y,L,R).
 

/*========================================================================
   Update History
========================================================================*/

updateHistory(Input):-
   retract(lara:history(His1)),
   appendLists(His1,[Input],His2),
   assert(lara:history(His2)).


/*========================================================================
   Clear History
========================================================================*/

clearHistory:-
   retract(lara:history(_)),
   assert(lara:history([])).


/*========================================================================
   Update Readings
========================================================================*/

updateReadings(R):-
   retract(lara:readings(_)),
   assert(lara:readings(R)).


/*========================================================================
   Update Models
========================================================================*/

updateModels(R):-
   retract(lara:models(_)),
   assert(lara:models(R)).


/*========================================================================
    Convert a list of words to a string
========================================================================*/

list2string([Word],Word).

list2string([Word|L],String2):-
   list2string(L,String1),
   name(Word,Codes1),
   name(String1,Codes2),
   appendLists(Codes1,[32|Codes2],Codes3),
   name(String2,Codes3).
